@@ -104,7 +104,7 @@ class AzureDBStream(dbstream.DBStream):
         con = pyodbc.connect(**connection_kwargs)
         cursor = con.cursor()
 
-        small_batch_size = int(2099 / len(columns_name))
+        small_batch_size = min(1000, int(2099 / len(columns_name)))
 
         print("Initiate send_to_azure...")
 
